# Welcome to Smart Cruise's documentation!

**smart-cruise** is a Python package for finding Pareto-optimal trajectories that balance
energy consumption and travel time. It uses dynamic programming with multi-objective
optimization to efficiently explore the trade-off space.

See the [README](presentation/readme.md) for scientific references.

:::{toctree}
:maxdepth: 2
:caption: Contents:

presentation/index
tutorials/index
reference/index
:::

# Indices and tables

* {ref}`genindex`
* {ref}`modindex`
* {ref}`search`
